@@ -1,10 +1,10 @@
 {
-    'name': "Manage your Gateway for ThingsInTouch Devices",
-    'summary': "Receive and send data to your net of sensors and devices",       
+    'name': "Gateway for ThingsInTouch Devices",
+    'summary': "Manage your Gateways and connect to your net of sensors and devices",       
     'description': """Receive and send data
-        to your net of sensors and devices""",
+        from/to your net of sensors and devices""",
 
-    'version': '12.0.1.0.1',
+    'version': '12.0.1.0.2',
     'category': 'Things',
     'website': "http://www.thingsintouch.com",
     'author': "thingsintouch.com",
